CREATE TABLE IF NOT EXISTS device_tab
(
    tab_id serial,
    tab_name character varying(50) COLLATE pg_catalog."default",
    tab_default_options json,
    tab_url character varying(200) COLLATE pg_catalog."default",
    tab_order smallint DEFAULT 99,
    tab_web_id integer,
    CONSTRAINT tab_primary_key PRIMARY KEY (tab_id),
    CONSTRAINT tab_name_unique UNIQUE (tab_name),
    CONSTRAINT "tab_foreignKey_web_plugin" FOREIGN KEY (tab_web_id)
        REFERENCES public.esia_web_plugin (web_id) MATCH FULL
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS device_tab OWNER to esia;


CREATE TABLE IF NOT EXISTS public.device_tab_linked
(
    tab_linked_device_id bigint NOT NULL,
    tab_linked_tab_id integer NOT NULL,
    tab_linked_order smallint,
    tab_linked_option json,
    CONSTRAINT "linked_primaryKey" PRIMARY KEY (tab_linked_device_id, tab_linked_tab_id),
    CONSTRAINT "linked_foreignKey_device_id" FOREIGN KEY (tab_linked_device_id)
        REFERENCES public.esia_device (device_id) MATCH FULL
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT "linked_foreignKey_device_tab" FOREIGN KEY (tab_linked_tab_id)
        REFERENCES public.device_tab (tab_id) MATCH FULL
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS public.device_tab_linked OWNER to esia;

-- FUNCTION: public.trigger_notify_serviceCron()

-- DROP FUNCTION IF EXISTS public.trigger_notify_serviceCron();
ALTER TABLE esia_plugins ADD COLUMN plugin_cron_type character varying(10);
ALTER TABLE esia_plugins ADD COLUMN plugin_cron_only_existing boolean;

CREATE TABLE IF NOT EXISTS public.esia_cron_plugin
(
    cron_id bigserial,
    cron_plugin_id integer NOT NULL,
    cron_interval interval,
    cron_status character varying(10) COLLATE pg_catalog."default",
    cron_last_exec timestamp with time zone,
    cron_next_exec timestamp with time zone,
    cron_log_file character varying(200) COLLATE pg_catalog."default",
    cron_retries integer NOT NULL DEFAULT 1,
    cron_retries_interval interval,
    cron_parameter character varying(200) COLLATE pg_catalog."default",
    cron_delete boolean DEFAULT false,
    CONSTRAINT "cron_primaryKey" PRIMARY KEY (cron_id),
    CONSTRAINT "cron_foreignKey_plugin_id" FOREIGN KEY (cron_plugin_id)
        REFERENCES public.esia_plugins (plugin_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);
CREATE TABLE IF NOT EXISTS public.esia_cron_error
(
    cron_error_id bigserial,
    cron_id bigint NOT NULL,
    cron_date timestamp without time zone NOT NULL,
    cron_logfile character varying(200) COLLATE pg_catalog."default",
    cron_delete boolean DEFAULT false,
    CONSTRAINT esia_cron_error_pkey PRIMARY KEY (cron_error_id),
    CONSTRAINT "cron_error_foreignKey_cron_id" FOREIGN KEY (cron_id)
        REFERENCES public.esia_cron_plugin (cron_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS public.esia_cron_error OWNER to esia;

CREATE INDEX IF NOT EXISTS cron_index_plugin_id
    ON public.esia_cron_plugin USING btree
    (cron_plugin_id ASC NULLS LAST)
    TABLESPACE pg_default;

CREATE OR REPLACE FUNCTION public.trigger_notify_serviceCron()
    RETURNS trigger
    LANGUAGE 'plpgsql'
AS $BODY$
 DECLARE v_payload JSON;
BEGIN
	IF TG_OP = 'INSERT' THEN
		v_payload := json_build_object('TYPE','SERVICE','COMMAND','ADD','ID',NEW.cron_id);
	ELSEIF TG_OP = 'UPDATE' THEN
		v_payload := json_build_object('TYPE','SERVICE','COMMAND','UPDATE','ID',NEW.cron_id);
	END IF;
	PERFORM pg_notify('esiacronchannel',v_payload::text);
    RETURN NEW;
END;
$BODY$;
ALTER FUNCTION public.trigger_notify_serviceCron() OWNER TO esia;
CREATE TRIGGER "notifyCronDaemon"
    AFTER INSERT OR UPDATE
    ON public.esia_cron_plugin
    FOR EACH ROW
    EXECUTE FUNCTION public.trigger_notify_serviceCron();
