--optimisations
CREATE OR REPLACE VIEW view_actual_error AS 
 SELECT esia_error_happen.happen_id,
	esia_error_happen.happen_device_id,
    esia_error_happen.happen_service_id,
    esia_errors.error_type
   FROM esia_error_happen
     JOIN esia_errors ON esia_errors.error_id = esia_error_happen.happen_error_id
  WHERE esia_error_happen.happen_acquitte = 0;

ALTER TABLE view_actual_error
  OWNER TO esia;

-- View: view_node_state

-- DROP VIEW view_node_state;

CREATE OR REPLACE VIEW view_node_state AS 
 SELECT t2.device_id,
    COALESCE(t2.warning, 0::bigint) AS warning,
    COALESCE(t2.critical, 0::bigint) AS critical,
    COALESCE(t2.unknown, 0::bigint) AS unknown,
    COALESCE(t2.ok, 0::bigint) AS ok
   FROM crosstab('SELECT device_id::integer as rowid,error_type::text as attribute,nbr::bigint
		FROM	(SELECT device_id,error_type, count (*) as nbr
			FROM (SELECT device_id, happen_id,error_type
					FROM esia_device
					JOIN view_actual_error ON view_actual_error.happen_device_id = device_id
					AND device_delete=FALSE
					) AS T1
			GROUP BY device_id,error_type
			UNION 
			SELECT service_device_id,''ok'',count(*) AS nbr
			FROM esia_services
			WHERE service_previous_state = 0 
				AND service_delete = false 
			GROUP BY service_device_id
		) AS T2
		ORDER BY 1,2'::text, 'SELECT * FROM (SELECT error_type FROM  esia_errors UNION SELECT ''ok'') AS T1 ORDER BY 1;'::text) t2(device_id integer, critical bigint, ok bigint, unknown bigint, warning bigint);

ALTER TABLE view_node_state
  OWNER TO esia;

-- Function: getdeviceingroup(integer, integer)

--DROP FUNCTION getAllChildDeviceGroup(integer);

-- Function: getallchilddevicegroup(integer)

-- DROP FUNCTION getallchilddevicegroup(integer);

CREATE OR REPLACE FUNCTION getallchilddevicegroup(IN groupid integer)
  RETURNS TABLE(group_id integer, group_name character varying, group_parent integer, group_order integer) AS
$BODY$
    BEGIN
IF groupid IS NULL
THEN
RETURN QUERY SELECT device_group_id, device_group_name,device_group_parent,device_group_order
       FROM esia_device_group;
ELSE
RETURN QUERY
WITH RECURSIVE q AS (SELECT device_group_id, device_group_name,device_group_parent,device_group_order
       FROM esia_device_group
WHERE device_group_id = groupid
      UNION ALL
     SELECT m.device_group_id, m.device_group_name,m.device_group_parent,m.device_group_order
       FROM esia_device_group m
       JOIN q ON q.device_group_id = m.device_group_parent)
SELECT * FROM q;
END IF;
   END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION getallchilddevicegroup(integer)
  OWNER TO esia;






CREATE INDEX "group_in_index_groupId"
  ON esia_device_group_in
  USING btree
  (group_in_device_group_id);
CREATE INDEX "group_in_index_deviceId"
  ON esia_device_group_in
  USING btree
  (group_in_device_id);


CREATE INDEX "access_index_deviceId"
  ON esia_group_device_access
  USING btree
  (access_device_id);

CREATE INDEX "access_index_groupId"
  ON esia_group_device_access
  USING btree
  (access_group_id);

CREATE INDEX device_group_index_parent
  ON esia_device_group
  USING btree
  (device_group_parent);

CREATE INDEX error_index_type
  ON esia_errors
  USING btree
  (error_type COLLATE pg_catalog."default");


CREATE INDEX widget_index_view_id
  ON dashboard_widget
  USING btree
  (widget_view_id);



CREATE INDEX widget_index_tile_id
  ON dashboard_widget
  USING btree
  (widget_tile_id);


CREATE INDEX tile_index_dashboard_id
  ON dashboard_tile
  USING btree
  (tile_dashboard_id);




CREATE INDEX grant_index_access
  ON esia_privilege_grantedto
  USING btree
  (grant_acces);

CREATE INDEX "grant_index_groupId"
  ON esia_privilege_grantedto
  USING btree
  (grant_group_id);


CREATE INDEX "grant_index_privilegeId"
  ON esia_privilege_grantedto
  USING btree
  (grant_privilege_id);


CREATE INDEX search_index_search_name
  ON esia_search
  USING btree
  (search_name COLLATE pg_catalog."default");
CREATE INDEX web_index_activate
  ON esia_web_plugin
  USING btree
  (web_activate);
CREATE INDEX rrd_index_plugin_id
  ON rrd_plugins
  USING btree
  (rrd_plugin_id);
CREATE INDEX localization_index_image_id
  ON esia_localization
  USING btree
  (localization_image_id);
CREATE INDEX config_visibility
  ON esia_configuration
  USING btree
  (config_visibility);

CREATE INDEX device_index_delete
  ON esia_device
  USING btree
  (device_delete);

CREATE INDEX service_index_previous_state
  ON esia_services
  USING btree
  (service_previous_state);


CREATE INDEX member_index_group_id
  ON esia_memberof
  USING btree
  (member_group_id);

CREATE INDEX member_index_user_id
  ON esia_memberof
  USING btree
  (member_user_id);

--
-- GLOBAL
--

-- ESIA_CONFIGURATION pour bien faire correspondre les graph avec le schema proposé par Esia

UPDATE esia_configuration
SET config_value='SNMP\S*LOAD'
WHERE config_key='SRV_CPU_LOAD';

UPDATE esia_configuration
SET config_value='SNMP\S*STORAGE'
WHERE config_key='SRV_HDD_LOAD';

UPDATE esia_configuration
SET config_value='SNMP\S*INTERFACE%'
WHERE config_key='SRV_INT_LOAD';

UPDATE esia_configuration
SET config_value='SNMP\S*MEM'
WHERE config_key='SRV_RAM_LOAD';
